"use strict";

let { classes: Cc, interfaces: Ci, results: Cr, utils: Cu } = Components;
Cu.import("resource://gre/modules/XPCOMUtils.jsm");
XPCOMUtils.importRelative(this, "base/arDialog.jsm");
XPCOMUtils.importRelative(this, "base/arPrototype.jsm");
XPCOMUtils.importRelative(this, "base/arTimer.jsm");
XPCOMUtils.importRelative(this, "UnMHTSave.jsm");

let EXPORTED_SYMBOLS = ["UnMHTAdditionalDialogClass"];

/**
 * 追加ファイルダイアログ
 *
 * 結果 {Promise<Array.<string>>}
 *   resolve: 追加の URI
 *   reject: {number}
 *           UnMHTSave.RESULT_CANCEL
 *
 * @param   {nsIDOMWindow} window
 *          対象のウィンドウ
 * @extends    arDialog
 * @implements arIDialog
 */
function UnMHTAdditionalDialogClass(window) {
  arDialog.call(this, window);
}
UnMHTAdditionalDialogClass.prototype = {
  /* ==== arIDialog インターフェース ==== */
  
  /**
   * ダイアログを OK したイベント
   *
   * @returns {boolean}
   *          ダイアログを閉じるか
   */
  onDialogAccept: function() {
    let result = this.result;
    let addURIs = UnMHTSave.parseAdditionalURIs(this.el("add_uris").value);
    arTimer.setTimeout(function() {
      result.resolve(addURIs);
    }.bind(this), 100);
    
    return true;
  },
  
  /**
   * ダイアログをキャンセルしたイベント
   *
   * @returns {boolean}
   *          ダイアログを閉じるか
   */
  onDialogCancel: function() {
    let result = this.result;
    arTimer.setTimeout(function() {
      result.reject(UnMHTSave.RESULT_CANCEL);
    }.bind(this), 100);
    
    return true;
  }
};
arPrototype.extend(UnMHTAdditionalDialogClass, arDialog);
