"use strict";

let { classes: Cc, interfaces: Ci, results: Cr, utils: Cu } = Components;
Cu.import("resource://gre/modules/XPCOMUtils.jsm");
XPCOMUtils.importRelative(this, "UnMHT.jsm");
XPCOMUtils.importRelative(this, "UnMHTStringBundle.jsm");

let EXPORTED_SYMBOLS = ["UnMHTFennecOverlay"];

/**
 * UI のオーバーレイ生成関数
 *
 * @param   {nsIXULWindow} window
 *          対象のウィンドウ
 * @param   {arFennecWindowOverlay} overlay
 *          オーバーレイ
 */
function UnMHTFennecOverlay(window, overlay) {
  /* Fennec のイベントハンドラは外の環境が見えない */
  let _UnMHT = UnMHT;
  
  overlay.menu.addItem({
    label: UnMHTStringBundle.get("menuitem.save.single.instant"),
    icon: "data:image/png;base64,"
      + "iVBORw0KGgoAAAANSUhEUgAAAEAAAABACAYAAACqaXHeAAAACXBIWXMAAA3XAAAN1wFCKJt4AAAK"
      + "TWlDQ1BQaG90b3Nob3AgSUNDIHByb2ZpbGUAAHjanVN3WJP3Fj7f92UPVkLY8LGXbIEAIiOsCMgQ"
      + "WaIQkgBhhBASQMWFiApWFBURnEhVxILVCkidiOKgKLhnQYqIWotVXDjuH9yntX167+3t+9f7vOec"
      + "5/zOec8PgBESJpHmomoAOVKFPDrYH49PSMTJvYACFUjgBCAQ5svCZwXFAADwA3l4fnSwP/wBr28A"
      + "AgBw1S4kEsfh/4O6UCZXACCRAOAiEucLAZBSAMguVMgUAMgYALBTs2QKAJQAAGx5fEIiAKoNAOz0"
      + "ST4FANipk9wXANiiHKkIAI0BAJkoRyQCQLsAYFWBUiwCwMIAoKxAIi4EwK4BgFm2MkcCgL0FAHaO"
      + "WJAPQGAAgJlCLMwAIDgCAEMeE80DIEwDoDDSv+CpX3CFuEgBAMDLlc2XS9IzFLiV0Bp38vDg4iHi"
      + "wmyxQmEXKRBmCeQinJebIxNI5wNMzgwAABr50cH+OD+Q5+bk4eZm52zv9MWi/mvwbyI+IfHf/ryM"
      + "AgQAEE7P79pf5eXWA3DHAbB1v2upWwDaVgBo3/ldM9sJoFoK0Hr5i3k4/EAenqFQyDwdHAoLC+0l"
      + "YqG9MOOLPv8z4W/gi372/EAe/tt68ABxmkCZrcCjg/1xYW52rlKO58sEQjFu9+cj/seFf/2OKdHi"
      + "NLFcLBWK8ViJuFAiTcd5uVKRRCHJleIS6X8y8R+W/QmTdw0ArIZPwE62B7XLbMB+7gECiw5Y0nYA"
      + "QH7zLYwaC5EAEGc0Mnn3AACTv/mPQCsBAM2XpOMAALzoGFyolBdMxggAAESggSqwQQcMwRSswA6c"
      + "wR28wBcCYQZEQAwkwDwQQgbkgBwKoRiWQRlUwDrYBLWwAxqgEZrhELTBMTgN5+ASXIHrcBcGYBie"
      + "whi8hgkEQcgIE2EhOogRYo7YIs4IF5mOBCJhSDSSgKQg6YgUUSLFyHKkAqlCapFdSCPyLXIUOY1c"
      + "QPqQ28ggMor8irxHMZSBslED1AJ1QLmoHxqKxqBz0XQ0D12AlqJr0Rq0Hj2AtqKn0UvodXQAfYqO"
      + "Y4DRMQ5mjNlhXIyHRWCJWBomxxZj5Vg1Vo81Yx1YN3YVG8CeYe8IJAKLgBPsCF6EEMJsgpCQR1hM"
      + "WEOoJewjtBK6CFcJg4Qxwicik6hPtCV6EvnEeGI6sZBYRqwm7iEeIZ4lXicOE1+TSCQOyZLkTgoh"
      + "JZAySQtJa0jbSC2kU6Q+0hBpnEwm65Btyd7kCLKArCCXkbeQD5BPkvvJw+S3FDrFiOJMCaIkUqSU"
      + "Eko1ZT/lBKWfMkKZoKpRzame1AiqiDqfWkltoHZQL1OHqRM0dZolzZsWQ8ukLaPV0JppZ2n3aC/p"
      + "dLoJ3YMeRZfQl9Jr6Afp5+mD9HcMDYYNg8dIYigZaxl7GacYtxkvmUymBdOXmchUMNcyG5lnmA+Y"
      + "b1VYKvYqfBWRyhKVOpVWlX6V56pUVXNVP9V5qgtUq1UPq15WfaZGVbNQ46kJ1Bar1akdVbupNq7O"
      + "UndSj1DPUV+jvl/9gvpjDbKGhUaghkijVGO3xhmNIRbGMmXxWELWclYD6yxrmE1iW7L57Ex2Bfsb"
      + "di97TFNDc6pmrGaRZp3mcc0BDsax4PA52ZxKziHODc57LQMtPy2x1mqtZq1+rTfaetq+2mLtcu0W"
      + "7eva73VwnUCdLJ31Om0693UJuja6UbqFutt1z+o+02PreekJ9cr1Dund0Uf1bfSj9Rfq79bv0R83"
      + "MDQINpAZbDE4Y/DMkGPoa5hpuNHwhOGoEctoupHEaKPRSaMnuCbuh2fjNXgXPmasbxxirDTeZdxr"
      + "PGFiaTLbpMSkxeS+Kc2Ua5pmutG003TMzMgs3KzYrMnsjjnVnGueYb7ZvNv8jYWlRZzFSos2i8eW"
      + "2pZ8ywWWTZb3rJhWPlZ5VvVW16xJ1lzrLOtt1ldsUBtXmwybOpvLtqitm63Edptt3xTiFI8p0in1"
      + "U27aMez87ArsmuwG7Tn2YfYl9m32zx3MHBId1jt0O3xydHXMdmxwvOuk4TTDqcSpw+lXZxtnoXOd"
      + "8zUXpkuQyxKXdpcXU22niqdun3rLleUa7rrStdP1o5u7m9yt2W3U3cw9xX2r+00umxvJXcM970H0"
      + "8PdY4nHM452nm6fC85DnL152Xlle+70eT7OcJp7WMG3I28Rb4L3Le2A6Pj1l+s7pAz7GPgKfep+H"
      + "vqa+It89viN+1n6Zfgf8nvs7+sv9j/i/4XnyFvFOBWABwQHlAb2BGoGzA2sDHwSZBKUHNQWNBbsG"
      + "Lww+FUIMCQ1ZH3KTb8AX8hv5YzPcZyya0RXKCJ0VWhv6MMwmTB7WEY6GzwjfEH5vpvlM6cy2CIjg"
      + "R2yIuB9pGZkX+X0UKSoyqi7qUbRTdHF09yzWrORZ+2e9jvGPqYy5O9tqtnJ2Z6xqbFJsY+ybuIC4"
      + "qriBeIf4RfGXEnQTJAntieTE2MQ9ieNzAudsmjOc5JpUlnRjruXcorkX5unOy553PFk1WZB8OIWY"
      + "EpeyP+WDIEJQLxhP5aduTR0T8oSbhU9FvqKNolGxt7hKPJLmnVaV9jjdO31D+miGT0Z1xjMJT1Ir"
      + "eZEZkrkj801WRNberM/ZcdktOZSclJyjUg1plrQr1zC3KLdPZisrkw3keeZtyhuTh8r35CP5c/Pb"
      + "FWyFTNGjtFKuUA4WTC+oK3hbGFt4uEi9SFrUM99m/ur5IwuCFny9kLBQuLCz2Lh4WfHgIr9FuxYj"
      + "i1MXdy4xXVK6ZHhp8NJ9y2jLspb9UOJYUlXyannc8o5Sg9KlpUMrglc0lamUycturvRauWMVYZVk"
      + "Ve9ql9VbVn8qF5VfrHCsqK74sEa45uJXTl/VfPV5bdra3kq3yu3rSOuk626s91m/r0q9akHV0Ibw"
      + "Da0b8Y3lG19tSt50oXpq9Y7NtM3KzQM1YTXtW8y2rNvyoTaj9nqdf13LVv2tq7e+2Sba1r/dd3vz"
      + "DoMdFTve75TsvLUreFdrvUV99W7S7oLdjxpiG7q/5n7duEd3T8Wej3ulewf2Re/ranRvbNyvv7+y"
      + "CW1SNo0eSDpw5ZuAb9qb7Zp3tXBaKg7CQeXBJ9+mfHvjUOihzsPcw83fmX+39QjrSHkr0jq/dawt"
      + "o22gPaG97+iMo50dXh1Hvrf/fu8x42N1xzWPV56gnSg98fnkgpPjp2Snnp1OPz3Umdx590z8mWtd"
      + "UV29Z0PPnj8XdO5Mt1/3yfPe549d8Lxw9CL3Ytslt0utPa49R35w/eFIr1tv62X3y+1XPK509E3r"
      + "O9Hv03/6asDVc9f41y5dn3m978bsG7duJt0cuCW69fh29u0XdwruTNxdeo94r/y+2v3qB/oP6n+0"
      + "/rFlwG3g+GDAYM/DWQ/vDgmHnv6U/9OH4dJHzEfVI0YjjY+dHx8bDRq98mTOk+GnsqcTz8p+Vv95"
      + "63Or59/94vtLz1j82PAL+YvPv655qfNy76uprzrHI8cfvM55PfGm/K3O233vuO+638e9H5ko/ED+"
      + "UPPR+mPHp9BP9z7nfP78L/eE8/sl0p8zAAAAIGNIUk0AAHolAACAgwAA+f8AAIDpAAB1MAAA6mAA"
      + "ADqYAAAXb5JfxUYAAArpSURBVHja7Jt5lBTVFcZ/I8swERxBcBCBCWsQAsMSlS0YIyrIuASiwQBB"
      + "QIYtUZKA4LgEEj0wIBEJKBgkiAQRkCgDYTMYNxQTE5QlgAjKjOjgBGaQfc0f9dWZl3eqqqurG+Qc"
      + "uOf06a7q6qr37rvvu9/93uuU06dPcz7bRZzndsEBFxxwnlt5+8Q99w45E89JATKABkAmUBNIB1KB"
      + "o0Ap8CWwC/hEn5OKzrNnPhPOAUm0bwHXAzcD1wJZ6nAsOwpsAdYBy4C/A/vPWgQkweoDw4CeQC3j"
      + "/F7gA2C7Xoc1yuUUDZmKkEZyVhaQA+wBXgSm6nfnrAPqAGOAXhrpU8C7wCvAW8BHwEFd2wLYBxR4"
      + "3OcSoDnQFuih6LkfGAzMAx7XNDlnQDBNjdoM9AdOAs8ArYD2wAQ54jhwt0L7Q+C3PvfbD7wDTNLv"
      + "s3S/k0A/YCMwHrj4XHBAczU2Vw2aDTQFhmrE3SjrreN5wDU63xe4PcQzNup+TYBZiq5Rcmrzb9IB"
      + "PwLWaqQBRmqEPjOu6QasB14AvuORGWYDbUI+rwAYoKmxTp1/D/jJN+GAocDLQGUdHwFeNb7P0Ggv"
      + "BZoF3OdS4DXgtjie/T7QCXhKmWa+QPesOaA7ME0j6NoWA6Fba1rcHeJepcAOjWqFONpwDBhu4MjU"
      + "kM9LOAvcCMz1OP8fvedoZCoF3OMLIF/h+4qyQVT7jdLpOOBP4hCLz1QEtAIWCfVt2yW0n+HT+ePA"
      + "cuFGI2AQcIPCt32CODZeDkjV4Fx9JhzgIvwloqlemDDS4/xe4Emlsls04i4X+DZwk6bLGn1OieiE"
      + "XJGlNGWK9GQ74FGRl3X6bFsV6/gAkKfU9StjiphTr7pxfD2wUs7oEtEJw4B/Ad8FxibTAd/T6B5R"
      + "Pv80xvXzhPyjga8CIqqax/l2miqTIzhgH3CPcOB+AWtSHJCr0JwopD/oc91WgWQvYUKQVdd08rNd"
      + "EaNgg7DIBciEHdBBwPW5MSoHPK6boHn+WsiGZgRUhsXAnxMAxcnAbk2lTok6oI9bTgvQ8CEdLyv0"
      + "wlglgw572SqgKAEH7FV7AQYm4oDLVI2dAubo3C+V670YnZ+VU2p6QixuvfDBz24Gngc6JqJ/qHi6"
      + "VeJLJAfcoLm6EtimkPq9vrNxoK5PWTtCoLlW6DxF5W1+gBhSFfiZSuiZorvx2sfAaqXDLlEd0E3v"
      + "CxS203X8OPCQdW0T67g/sFMkZRHQWA2ZK/rbyOeZvwD+YBwPEHeoFMEJi/SeHcUBqQaAvK6Ry1To"
      + "Pgy84cESAWoAfwWeU7laX9Nmp6Uf1PN45qdKocOBNy36PSmCA97We9sg7cDPAXX1Kga6CkyGidyg"
      + "2n6DpQt0U6e7Sr3J9klntZQFbJtlTK0Ros+uDdHUice2q0i7EmgYrwOa6LtqorKjgKeN709ZRUcN"
      + "lb6VlTpnBDSsnkcKLFEx49o/rFSYovohHjtpMNDG8TqggfH9fINcmPai2KFrXwOdBXixiirbXgAK"
      + "rXN/sY5/GAEQt+q9fjwOKA9cbhwfCbh5vpXfw1iWR20/w4fVHbWmTq04HfC5QbxCOyAduMI4/r5y"
      + "uV+YuVZBKB4LdFta514CNvnoBkXW/a+IUB8E8hQvB9RQqepaU+Vw2/pJHfrIYo5NAxrUwEqBxwMQ"
      + "/ohHMZUapwOOG84L7YAMOcEEoDs8kHyyGt/FoMlpMYqQdkBF43gOjkTuZ4es48NxOiDVIFihHVDN"
      + "Q1C40/JinkBrjEL1AeO7u0Shvayz8bkwBiW2JbtjPmJMkFUxADq0A6p4oG0zypTbturkEDUKEZ/H"
      + "jOuf9ACsysAPLCcWBzQ+xZq7u/BeSQoyFzP2xJsFvEBvuN7HiQO8aX3/CGWCaR0PZG+n86gomh6j"
      + "8ekqyFx7x3B4WGtkkKLQDjiF99J0e9UFLQLm+QDK1geyVQuY08i1B4ETMRqfaaXj+RHosLsYsyMe"
      + "BxzyyP2FCsk7cZast/nc7xiOPr9Gx6Mko5UXRXaBb02IxrcwPm8O+RvT6igjFccbAaUeqs9M8XM3"
      + "AwStJxxWHb5Ax0+L59cWiD0csgMmXkyKEP5tlHH+rT6FdkCRAU7uVOgpLWCAdIJY8/cQzprdg0pF"
      + "rrKUExLIMowydoUcGK+5qXtl2DRjMjB3uWqd2FRXnNXcWZqX44wCJWguj9cojI2TLvfWcz6LUAQh"
      + "ISdbeLYkXj2gCGdJ2o2AbHUgRx0Yr/zdX7pAwxhEpI8QfCjOmuJ9MRqfpmtLcJbPoyjEPZVBVkkd"
      + "ilsQ+afea2sEx2hULjZyeHeBzCZFhJfIcZ+c2ANnk0NjSV4/DmjTYOXt1jFYYpDo6gq302Jd7Adm"
      + "6zUClyucCi1Vxy1X98g5o8UT3laVeEoN6SgxpbJycqo4QDs5b68cfFqZ5zhwlaZb1LWBQdIz3lPG"
      + "iuSArxS23YT6hT7XXS2l5oQ63Nmiu+Ds8vKyE+q4V6EyUMi9Xu1YITyKlQlqG3rlWEJstQtKZ0vk"
      + "gHoaNZdZFVG2bW2yMGCYpeyWCkw/xNnQdFAR9YUipFTEarxGPE/hmi55LUuOvE6vXDnjCRGtAz5t"
      + "nqhCbrmcRqIOmIqzavuSzlWV2povKrwF+LmwxN1huUUaglcBUkHKTm/hQpo67hZFBQLghcoA9Shb"
      + "Q2wpql0i5XiKVUuMEviV4izIhrIgWfxLpb1+hj7wvqSwh5RfP5buVtuovbPw3/xUSZ3tTdk+g2Hq"
      + "7ARDuzsh0MwyKPBekbGlqjt2qgpNwVm+c2n3rzUICTvArepSFIJmbncFzIoCnFutuTwFb+3f1Q3v"
      + "wlm42Geo0CNFeZdQtvurUNS6h+bzoxJMr9FUyBNYPqfrc43PSXHAVtHQgZTt5Civ49UGU3tE1d9s"
      + "hekHFpW1ZbSFmlo1da8SfbdfTrIlrMUqjpbibMGZI4S/UQ6oKoCsjLMRI7R2GGaP0O9UBE0XIE1T"
      + "usuTU65V2G32qOeDnnudSNIdSpu5esa+ADG1hSFz/1RzvYOiaoQRqVNw9ggkxQGlwL1iVU9phKYJ"
      + "iS+S999Qg1Ybv/NKQVcKLLsL/VG+zgb+6/P8miJafeXUfOFGgUXc3EWV5bo+KVPAtdUCrz4421lc"
      + "hWerXtUEirFobjkB5FXWyE7EX7uvK5xJMXJ9O+O4qlJkd2WFqfFIZ/HsEssTwJjgtkqNa6jUtw3v"
      + "XWSmrNVSoVpgcP9+yiYTLUUagzkOEn60Ulpeoc8pwN+UJaqrdE8/Ew5AU+GPxnEvjf5Og7EFKbcV"
      + "Ra/XemDGMUVGXZ/fPmupSjfhLJ/ZCyujg+r/KBhgW45Qe6Tm9AMB6u5tKqVrqOPu6k6akdvX4uww"
      + "WYb/pipTrsPIGIMEdo+JS/QIoN5JcwDq9CapPaNEcad76O87NEKd+P+1hmIRnWcD6gwvAJ1iHG8Q"
      + "FW8tBw6OoTInZQqY9rzm4Bo1ZLuiw9z9tVEjlKkS+FVNkeqKmtfluFsI3mZTUc8zp0cHTb8eundx"
      + "lE4k+n+BbZLIblcDZgjopis3X2rohPkiNCVGXdBQYbxM0TLXElhSpewu1HNMkTRHJfXiRDqQrL/M"
      + "LFEHOyoV9lXHjspJu3E2XF7m8/uvBaJbNaIN1fFmRjH0Cc7ukwXiDieS0fBk/mfoNM7Gprc08h3F"
      + "9toYefyIjy5YRWQo23BIgbjFu2KemyIow2fVAaaViLe7u0YycJapMjT/q+Isv1Uw6oPDYoNF6vxu"
      + "fT7JGbSUC/8eP8/tfwMAnoubHjQMpl4AAAAASUVORK5CYII="
  }, function() {
    try {
      _UnMHT.quicksave(window);
    } catch (e) {
      Cu.reportError(e + "\n" + e.stack);
    }
  });
}
