"use strict";

let { classes: Cc, interfaces: Ci, results: Cr, utils: Cu } = Components;

let EXPORTED_SYMBOLS = ["UnMHTTreeScanner"];

/**
 * DOM ツリー走査
 *
 * @param   {nsIDOMWindow} window
 *          実行中のウィンドウ
 * @param   {nsIDOMElement} startNode
 *          開始要素
 */
function UnMHTTreeScanner(window, startNode) {
  this.gen = this._getGenerator(window, startNode);
}
UnMHTTreeScanner.prototype = {
  isHead: false,   /** HEAD 要素内か
                    *  @type {boolean} */
  gen: null,       /** DOM ツリー走査ジェネレータ
                    *  @type {Generator} */
  
  /**
   * 進捗状況 (0-1)
   * 走査した HTMLElement の数の割合
   *   @type {number}
   */
  get progress() {
    let p = this._progress;
    if (p > 1) {
      return 1;
    }
    return p;
  },
  
  /**
   * 破棄
   */
  destruct: function() {
    if (this.gen) {
      this.gen.close(); 
      this.gen = null;
    }
  },
  
  /* ==== private ==== */
  
  _progress: 0,     /** 進捗状況 (0-1)
                     *  走査した HTMLElement の数の割合
                     *  状況によっては計算が合わない事もあり 1 を越えたりする
                     *  @type {number} */

  /**
   * 要素を返すジェネレータを作成する
   *
   * @param   {nsIDOMWindow} window
   *          実行中のウィンドウ
   * @param   {nsIDOMElement} startNode
   *          開始要素
   * @returns {Generator}
   *          要素を返すジェネレータ
   */
  _getGenerator: function(window, startNode) {
    let node = startNode;
    this.isHead = false;
    
    let i = 0;
    let nodeCount = 1;
    try {
      nodeCount = startNode.getElementsByTagName("*").length + 1;
    } catch (e) {
    }
    while (node) {
      if (node instanceof Ci.nsIDOMHTMLHeadElement) {
        this.isHead = true;
      }
      
      this._progress = i / nodeCount;
      
      yield node;
      if (node instanceof Ci.nsIDOMElement) {
        i ++;
      }
      
      if (node.firstChild) {
        node = node.firstChild;
      } else {
        while (node) {
          if (node.nextSibling) {
            if (node instanceof Ci.nsIDOMHTMLHeadElement) {
              this.isHead = false;
            }
            
            node = node.nextSibling;
            break;
          }
          node = node.parentNode;
          if (node == startNode) {
            this._progress = 1;
            yield false;
            return;
          }
        }
      }
    }
  }
};
