"use strict";

let { classes: Cc, interfaces: Ci, results: Cr, utils: Cu } = Components;
Cu.import("resource://gre/modules/XPCOMUtils.jsm");
XPCOMUtils.importRelative(this, "arPrototype.jsm");
XPCOMUtils.defineLazyGetter(this, "arArrayUtil", function() {
  XPCOMUtils.importRelative(this, "arArrayUtil.jsm");
  return arArrayUtil;
});

let EXPORTED_SYMBOLS = ["arFennecWindowOverlay"];

/**
 * 汎用オーバーレイ
 *
 * @param   {arWindowOverlay} owindow
 *          オーバーレイ
 */
function arGenericOverlay(owindow) {
  this._owindow = owindow;
}
arGenericOverlay.prototype = {
  /* ==== private ==== */
  
  _owindow: null, /** ウィンドウのオーバーレイ
                   *  @type {arFennecWindowOverlay} */
};

/**
 * menu 要素に対するオーバーレイ
 *
 * @param   {arFennecWindowOverlay} owindow
 *          オーバーレイ
 */
function arMenuOverlay(owindow) {
  arGenericOverlay.call(this, owindow);
}
arMenuOverlay.prototype = {
  /**
   * メニューアイテムを追加する
   *
   * @param   {object} attrs
   *          要素の属性
   * @param   {Function} oncommand
   *          command イベントのハンドラ
   */
  addItem: function(attrs, oncommand) {
    let NativeWindow = this._owindow.window.NativeWindow;
    let id = NativeWindow.menu.add(attrs.label,
                                   ("icon" in attrs)
                                   ? attrs.icon
                                   : "", oncommand);
    this._owindow.oinfo.menuIDs.push([NativeWindow.menu, id]);
  }

  /* ==== private ==== */
};
arPrototype.extend(arMenuOverlay, arGenericOverlay);

/**
 * Fennec オーバーレイ情報
 */
function arFennecWindowOverlayInfo() {
  this.menuIDs = [];
}
arFennecWindowOverlayInfo.prototype = {
  menuIDs: null,  /** 追加したメニュー ID
                  *  @type {Array.<[Menu,id]>} */
  
  /**
   * 破棄
   */
  destruct: function() {
    this.menuIDs = null;
  },

  /**
   * オーバーレイを解除する
   */
  unload: function() {
    this.menuIDs.forEach(function([menu, id]) {
      try {
        menu.remove(id);
      } catch (e) {
        /* 対象が既に閉じている等 */
      }
    });
    this.menuIDs = [];
  }
};

/**
 * Fennec のウィンドウに対するオーバーレイ
 *
 * @param   {NativeWindow} window
 *          対象のウィンドウ
 */
function arFennecWindowOverlay(window) {
  this._window = window;
  this._oinfo = new arFennecWindowOverlayInfo();
  
  XPCOMUtils.defineLazyGetter(this, "menu", function() {
    return new arMenuOverlay(this);
  });
};
arFennecWindowOverlay.prototype = {
  /**
   * 破棄
   */
  destruct: function() {
    this._window = null;
    this._oinfo = null;
  },
  
  /**
   * 対象のウィンドウ
   * @type {nsIXULWindow}
   */
  get window() {
    return this._window;
  },
  
  /**
   * オーバーレイ情報
   * @type {arWindowOverlayInfo}
   */
  get oinfo() {
    return this._oinfo;
  },
  
  /* ==== private ==== */
  
  _window: null, /** 対象のウィンドウ
                  *  @type {nsIXULWindow} */
  _oinfo: null   /** オーバーレイ情報
                  *  @type {arFennecWindowOverlayInfo} */
};
