"use strict";

let { classes: Cc, interfaces: Ci, results: Cr, utils: Cu } = Components;
Cu.import("resource://gre/modules/XPCOMUtils.jsm");
XPCOMUtils.importRelative(this, "Promise.jsm");
XPCOMUtils.importRelative(this, "arAppInfo.jsm");
XPCOMUtils.importRelative(this, "arPrototype.jsm");
XPCOMUtils.importRelative(this, "arTimer.jsm");
XPCOMUtils.defineLazyGetter(this, "arArrayUtil", function() {
  XPCOMUtils.importRelative(this, "arArrayUtil.jsm");
  return arArrayUtil;
});
XPCOMUtils.defineLazyGetter(this, "arFennecWindowOverlay", function() {
  XPCOMUtils.importRelative(this, "arFennecWindowOverlay.jsm");
  return arFennecWindowOverlay;
});
XPCOMUtils.defineLazyGetter(this, "arStylesheetLoader", function() {
  XPCOMUtils.importRelative(this, "arStylesheetLoader.jsm");
  return arStylesheetLoader;
});
XPCOMUtils.defineLazyGetter(this, "arWindowOverlay", function() {
  XPCOMUtils.importRelative(this, "arWindowOverlay.jsm");
  return arWindowOverlay;
});

let EXPORTED_SYMBOLS = ["arOverlayLoader"];

/**
 * オーバーレイの適用と解除
 */
let arOverlayLoader = {
  /**
   * オーバーレイをロードする
   *
   * @param   {nsIXULWindow} window
   *          対象のウィンドウ
   * @param   {Function} loadFunc
   *          オーバーレイ登録関数
   * @param   {boolean} isStartup
   *          スタートアップイベントか
   * @returns {Promise<boolean>}
   *          resolve: ロード完了したか
   */
  loadInto: function(window, loadFunc, isStartup) {
    let deferred = Promise.defer();
    
    let owindow
      = arAppInfo.isFennec
      ? new arFennecWindowOverlay(window)
      : new arWindowOverlay(window);
    let oinfo = owindow.oinfo;
    
    let f = function() {
      loadFunc(window, owindow);
      owindow.destruct();
      
      deferred.resolve(true);
    };
    
    if (isStartup) {
      /* スタートアップイベント中に insertItem を呼ぶと
       * ツールバーが強制的に表示されるため遅延させる */
      arTimer.setTimeout(f, 100);
    } else {
      f();
    }
    
    this._overlays.push([window, loadFunc, oinfo]);
    
    return deferred.promise;
  },
  
  /**
   * オーバーレイをアンロードする
   *
   * @param   {nsIXULWindow} window
   *          対象のウィンドウ
   * @param   {Function} loadFunc
   *          オーバーレイ登録関数
   * @param   {boolean} isShutdown
   *          シャットダウンイベントか
   */
  unloadFrom: function(window, loadFunc, isShutdown) {
    this._overlays = this._overlays.filter(function([w, f, oinfo]) {
      if (w == window && f == loadFunc) {
        /* CSS の登録は load 時で良いが、解除はアドオン全体の終了時だけ */
        oinfo.unload();
        oinfo.destruct();
        return false;
      }
      return true;
    }.bind(this));
  },
  
  /* ==== private ==== */
  
  _overlays: [] /** 適用したウィンドウとオーバーレイ情報
                 *  @type {Array.<[Window,Function,arWindowOverlayInfo]>} */
};
