"use strict";

let { classes: Cc, interfaces: Ci, results: Cr, utils: Cu } = Components;
Cu.import("resource://gre/modules/XPCOMUtils.jsm");
Cu.import("resource://gre/modules/Services.jsm");
XPCOMUtils.importRelative(this, "arPrefClass.jsm");
XPCOMUtils.importRelative(this, "arShutdownEvent.jsm");

let EXPORTED_SYMBOLS = ["arStringBundle"];

/**
 * StringBundle 管理
 *
 * @param   {string} uri
 *          バンドルの URI
 * @implements arIShutdownEventListener
 */
function arStringBundle(uri = "") {
  arShutdownEvent.addListener(this);
  
  this._uri = uri;
  arPref.addGlobalListener("general.useragent.locale",
                           function() {
                             this._updateBundle();
                           }.bind(this), this, true);
}
arStringBundle.prototype = {
  /**
   * StringBundle を読み込む
   *
   * @param   {string} uri
   *          バンドルの URI
   */
  loadBundle: function(uri) {
    this._uri = uri;
    this._updateBundle();
  },
  
  /**
   * StringBundle から文字列を取得する
   *
   * @param   {string} name
   *          取得する文字列の名前
   * @param   {Array} params
   *          フォーマット用のパラメータ
   *          不要ならば undefined
   * @returns {string}
   *          StringBundle の文字列
   */
  get: function(name, params) {
    try {
      if (params) {
        return this._bundle.formatStringFromName(name, params, params.length);
      } else {
        return this._bundle.GetStringFromName(name);
      }
    } catch (e) {
      Cu.reportError(name + "," + params + "\n" + e + "\n" + e.stack);
      return "";
    }
  },
  
  /**
   * キャッシュをクリアする
   */
  flushBundle: function() {
    Services.strings.flushBundles();
  },
  
  /* ==== arIShutdownEventListener ==== */
  
  /**
   * シャットダウンイベント
   *
   * @param   {object} data
   *          Bootstrap データ
   * @param   {number} reason
   *          理由
   */
  onShutdown: function(data, reason) {
    this.flushBundle();
    
    arPref.removeAllListeners(this);
  },
  
  /* ==== private ==== */

  _uri: "",      /** バンドルの URI
                  *  @type {string} */
  _bundle: null, /** StringBundle
                  *  @type {nsIStringBundle} */

  /**
   * バンドルを更新する
   */
  _updateBundle: function() {
    if (this._uri) {
      this._bundle = Services.strings.createBundle(this._uri);
    }
  }
};
