"use strict";

let { classes: Cc, interfaces: Ci, results: Cr, utils: Cu } = Components;
Cu.import("resource://gre/modules/Services.jsm");
Cu.import("resource://gre/modules/XPCOMUtils.jsm");
XPCOMUtils.importRelative(this, "base/arAppInfo.jsm");
XPCOMUtils.importRelative(this, "UnMHTPref.jsm");
XPCOMUtils.defineLazyGetter(this, "UnMHTStartupWindowHook", function() {
  XPCOMUtils.importRelative(this, "UnMHTStartupWindowHook.jsm");
  return UnMHTStartupWindowHook;
});
XPCOMUtils.defineLazyGetter(this, "UnMHTFennecStartupWindowHook", function() {
  XPCOMUtils.importRelative(this, "UnMHTFennecStartupWindowHook.jsm");
  return UnMHTFennecStartupWindowHook;
});
XPCOMUtils.defineLazyGetter(this, "arComponentLoader", function() {
  XPCOMUtils.importRelative(this, "base/arComponentLoader.jsm");
  return arComponentLoader;
});
XPCOMUtils.defineLazyGetter(this, "UnMHTContentPolicy", function() {
  XPCOMUtils.importRelative(this, "UnMHTContentPolicy.jsm");
  return UnMHTContentPolicy;
});
XPCOMUtils.defineLazyGetter(this, "UnMHTDocumentLoaderFactory", function() {
  XPCOMUtils.importRelative(this, "UnMHTDocumentLoaderFactory.jsm");
  return UnMHTDocumentLoaderFactory;
});
XPCOMUtils.defineLazyGetter(this, "UnMHTMhtmlProtocolHandler", function() {
  XPCOMUtils.importRelative(this, "UnMHTMhtmlProtocolHandler.jsm");
  return UnMHTMhtmlProtocolHandler;
});
XPCOMUtils.defineLazyGetter(this, "UnMHTProtocolHandler", function() {
  XPCOMUtils.importRelative(this, "UnMHTProtocolHandler.jsm");
  return UnMHTProtocolHandler;
});
XPCOMUtils.defineLazyGetter(this, "UnMHTStartupDLFRegisterer", function() {
  XPCOMUtils.importRelative(this, "UnMHTStartupDLFRegisterer.jsm");
  return UnMHTStartupDLFRegisterer;
});
XPCOMUtils.defineLazyGetter(this, "UnMHTStartupExtract", function() {
  XPCOMUtils.importRelative(this, "UnMHTStartupExtract.jsm");
  return UnMHTStartupExtract;
});
XPCOMUtils.defineLazyGetter(this, "UnMHTFennecPrefPage", function() {
  XPCOMUtils.importRelative(this, "UnMHTFennecPrefPage.jsm");
  return UnMHTFennecPrefPage;
});
let global = this;

let EXPORTED_SYMBOLS = ["startup"];

/**
 * 有効な場合の起動時、無効から有効への変更時 (更新含む)
 *
 * @param   {object} data
 *          Bootstrap データ
 * @param   {number} reason
 *          理由
 *            1: APP_STARTUP
 *            3: ADDON_ENABLE
 *            5: ADDON_INSTALL
 *            7: ADDON_UPGRADE
 *            8: ADDON_DOWNGRADE
 */
function startup(data, reason) {
  if (!arAppInfo.isThunderbird) {
    arComponentLoader.loadComponent(UnMHTDocumentLoaderFactory);
    arComponentLoader.loadComponent(UnMHTContentPolicy);
    if (UnMHTPref.getPref("protocol.mhtml")) {
      arComponentLoader.loadComponent(UnMHTMhtmlProtocolHandler);
    }
    arComponentLoader.loadComponent(UnMHTProtocolHandler);
  }
  
  if (arAppInfo.isFennec) {
    UnMHTFennecStartupWindowHook.onStartup(data, reason);
  } else {
    UnMHTStartupWindowHook.onStartup(data, reason);
  }
  if (!arAppInfo.isThunderbird) {
    UnMHTStartupDLFRegisterer.onStartup(data, reason);
  }
  if (!arAppInfo.isThunderbird && !arAppInfo.isFennec) {
    if (reason != 1) {
      UnMHTStartupExtract.onStartup(data, reason);
    }
  }
  if (arAppInfo.isFennec) {
    UnMHTFennecPrefPage.onStartup(data, reason);
  }
}
